@@ -26,6 +26,8 @@ import org.apache.mina.core.session.IoSession;
 /**
  * Something interested in being notified when the completion
  * of an asynchronous I/O operation : {@link IoFuture}. 
+ * 
+ * @param <F> The Future type
  *
  * @author <a href="http://mina.apache.org">Apache MINA Project</a>
  */
@@ -35,6 +37,10 @@ public interface IoFutureListener<F extends IoFuture> extends EventListener {
      * associated with the specified {@link IoFuture}.
      */
     IoFutureListener<IoFuture> CLOSE = new IoFutureListener<IoFuture>() {
+        /**
+         * {@inheritDoc}
+         */
+        @Override
         public void operationComplete(IoFuture future) {
             future.getSession().closeNow();
         }
