@@ -92,15 +92,11 @@ public abstract class AbstractIoSession implements IoSession {
 
     /**
      * An internal write request object that triggers session close.
-     * 
-     * @see #writeRequestQueue
      */
     public static final WriteRequest CLOSE_REQUEST = new DefaultWriteRequest(new Object());
 
     /**
      * An internal write request object that triggers message sent events.
-     * 
-     * @see #writeRequestQueue
      */
     public static final WriteRequest MESSAGE_SENT_REQUEST = new DefaultWriteRequest(DefaultWriteRequest.EMPTY_MESSAGE);
 
@@ -479,7 +475,7 @@ public abstract class AbstractIoSession implements IoSession {
         Queue<ReadFuture> readyReadFutures = (Queue<ReadFuture>) getAttribute(READY_READ_FUTURES_KEY);
         
         if (readyReadFutures == null) {
-            readyReadFutures = new ConcurrentLinkedQueue<ReadFuture>();
+            readyReadFutures = new ConcurrentLinkedQueue<>();
 
             Queue<ReadFuture> oldReadyReadFutures = (Queue<ReadFuture>) setAttributeIfAbsent(READY_READ_FUTURES_KEY,
                     readyReadFutures);
@@ -499,7 +495,7 @@ public abstract class AbstractIoSession implements IoSession {
         Queue<ReadFuture> waitingReadyReadFutures = (Queue<ReadFuture>) getAttribute(WAITING_READ_FUTURES_KEY);
         
         if (waitingReadyReadFutures == null) {
-            waitingReadyReadFutures = new ConcurrentLinkedQueue<ReadFuture>();
+            waitingReadyReadFutures = new ConcurrentLinkedQueue<>();
 
             Queue<ReadFuture> oldWaitingReadyReadFutures = (Queue<ReadFuture>) setAttributeIfAbsent(
                     WAITING_READ_FUTURES_KEY, waitingReadyReadFutures);
