@@ -178,8 +178,9 @@ public interface IoSession {
      *                    {@code false} to close this session after all queued
      *                    write requests are flushed.
      * @return The associated CloseFuture
-     * @deprecated Use either the closeNow() or the flushAndClose() methods
+     * @deprecated Use either the {@link #closeNow()} or the {@link #closeOnFlush()} methods
      */
+    @Deprecated
     CloseFuture close(boolean immediately);
 
     /**
@@ -203,7 +204,7 @@ public interface IoSession {
      * Closes this session after all queued write requests
      * are flushed. This operation is asynchronous.  Wait for the returned
      * {@link CloseFuture} if you want to wait for the session actually closed.
-     * @deprecated use {@link #close(boolean)}
+     * @deprecated use {@link #closeNow()}
      * 
      * @return The associated CloseFuture
      */
