@@ -98,10 +98,18 @@ public class ProtocolCodecFilter extends IoFilterAdapter {
 
         // Create the inner Factory based on the two parameters
         this.factory = new ProtocolCodecFactory() {
+            /**
+             * {@inheritDoc}
+             */
+            @Override
             public ProtocolEncoder getEncoder(IoSession session) {
                 return encoder;
             }
 
+            /**
+             * {@inheritDoc}
+             */
+            @Override
             public ProtocolDecoder getDecoder(IoSession session) {
                 return decoder;
             }
@@ -160,10 +168,18 @@ public class ProtocolCodecFilter extends IoFilterAdapter {
 
         // Create the inner factory based on the two parameters.
         this.factory = new ProtocolCodecFactory() {
+            /**
+             * {@inheritDoc}
+             */
+            @Override
             public ProtocolEncoder getEncoder(IoSession session) throws Exception {
                 return encoder;
             }
 
+            /**
+             * {@inheritDoc}
+             */
+            @Override
             public ProtocolDecoder getDecoder(IoSession session) throws Exception {
                 return decoder;
             }
@@ -180,6 +196,9 @@ public class ProtocolCodecFilter extends IoFilterAdapter {
         return (ProtocolEncoder) session.getAttribute(ENCODER);
     }
 
+    /**
+     * {@inheritDoc}
+     */
     @Override
     public void onPreAdd(IoFilterChain parent, String name, NextFilter nextFilter) throws Exception {
         if (parent.contains(this)) {
@@ -188,6 +207,9 @@ public class ProtocolCodecFilter extends IoFilterAdapter {
         }
     }
 
+    /**
+     * {@inheritDoc}
+     */
     @Override
     public void onPostRemove(IoFilterChain parent, String name, NextFilter nextFilter) throws Exception {
         // Clean everything
@@ -260,6 +282,9 @@ public class ProtocolCodecFilter extends IoFilterAdapter {
         }
     }
 
+    /**
+     * {@inheritDoc}
+     */
     @Override
     public void messageSent(NextFilter nextFilter, IoSession session, WriteRequest writeRequest) throws Exception {
         if (writeRequest instanceof EncodedWriteRequest) {
@@ -274,6 +299,9 @@ public class ProtocolCodecFilter extends IoFilterAdapter {
         }
     }
 
+    /**
+     * {@inheritDoc}
+     */
     @Override
     public void filterWrite(NextFilter nextFilter, IoSession session, WriteRequest writeRequest) throws Exception {
         Object message = writeRequest.getMessage();
@@ -334,6 +362,9 @@ public class ProtocolCodecFilter extends IoFilterAdapter {
         }
     }
 
+    /**
+     * {@inheritDoc}
+     */
     @Override
     public void sessionClosed(NextFilter nextFilter, IoSession session) throws Exception {
         // Call finishDecode() first when a connection is closed.
@@ -365,6 +396,10 @@ public class ProtocolCodecFilter extends IoFilterAdapter {
             super(encodedMessage, future, destination);
         }
 
+        /**
+         * {@inheritDoc}
+         */
+        @Override
         public boolean isEncoded() {
             return true;
         }
@@ -391,6 +426,10 @@ public class ProtocolCodecFilter extends IoFilterAdapter {
             // Do nothing
         }
 
+        /**
+         * {@inheritDoc}
+         */
+        @Override
         public void flush(NextFilter nextFilter, IoSession session) {
             Queue<Object> messageQueue = getMessageQueue();
 
@@ -416,6 +455,10 @@ public class ProtocolCodecFilter extends IoFilterAdapter {
             destination = writeRequest.getDestination();
         }
 
+        /**
+         * {@inheritDoc}
+         */
+        @Override
         public WriteFuture flush() {
             Queue<Object> bufferQueue = getMessageQueue();
             WriteFuture future = null;
