@@ -28,7 +28,6 @@ import java.util.concurrent.locks.ReentrantLock;
 
 import javax.net.ssl.SSLEngine;
 import javax.net.ssl.SSLEngineResult;
-import javax.net.ssl.SSLEngineResult.HandshakeStatus;
 import javax.net.ssl.SSLEngineResult.Status;
 import javax.net.ssl.SSLException;
 import javax.net.ssl.SSLHandshakeException;
@@ -62,7 +61,7 @@ import org.slf4j.LoggerFactory;
 /** No qualifier*/
 class SslHandler {
     /** A logger for this class */
-    private final static Logger LOGGER = LoggerFactory.getLogger(SslHandler.class);
+    private static final Logger LOGGER = LoggerFactory.getLogger(SslHandler.class);
 
     /** The SSL Filter which has created this handler */
     private final SslFilter sslFilter;
@@ -70,12 +69,12 @@ class SslHandler {
     /** The current session */
     private final IoSession session;
 
-    private final Queue<IoFilterEvent> preHandshakeEventQueue = new ConcurrentLinkedQueue<IoFilterEvent>();
+    private final Queue<IoFilterEvent> preHandshakeEventQueue = new ConcurrentLinkedQueue<>();
 
-    private final Queue<IoFilterEvent> filterWriteEventQueue = new ConcurrentLinkedQueue<IoFilterEvent>();
+    private final Queue<IoFilterEvent> filterWriteEventQueue = new ConcurrentLinkedQueue<>();
 
     /** A queue used to stack all the incoming data until the SSL session is established */
-    private final Queue<IoFilterEvent> messageReceivedEventQueue = new ConcurrentLinkedQueue<IoFilterEvent>();
+    private final Queue<IoFilterEvent> messageReceivedEventQueue = new ConcurrentLinkedQueue<>();
 
     private SSLEngine sslEngine;
 
@@ -120,7 +119,7 @@ class SslHandler {
     private ReentrantLock sslLock = new ReentrantLock();
     
     /** A counter of schedules events */
-    private final AtomicInteger scheduled_events = new AtomicInteger(0);
+    private final AtomicInteger scheduledEvents = new AtomicInteger(0);
 
     /**
      * Create a new SSL Handler, and initialize it.
@@ -128,7 +127,7 @@ class SslHandler {
      * @param sslContext
      * @throws SSLException
      */
-    /* no qualifier */SslHandler(SslFilter sslFilter, IoSession session) throws SSLException {
+    /* no qualifier */SslHandler(SslFilter sslFilter, IoSession session) {
         this.sslFilter = sslFilter;
         this.session = session;
     }
@@ -182,8 +181,6 @@ class SslHandler {
 
         // TODO : we may not need to call this method...
         // However, if we don't call it here, the tests are failing. Why?
-        sslEngine.beginHandshake();
-
         handshakeStatus = sslEngine.getHandshakeStatus();
 
         // Default value
@@ -306,7 +303,7 @@ class SslHandler {
     }
 
     /* no qualifier */void flushScheduledEvents() {
-        scheduled_events.incrementAndGet();
+        scheduledEvents.incrementAndGet();
 
         // Fire events only when the lock is available for this handler.
         if (sslLock.tryLock()) {
@@ -325,7 +322,7 @@ class SslHandler {
                         NextFilter nextFilter = event.getNextFilter();
                         nextFilter.messageReceived(session, event.getParameter());
                     }
-                } while (scheduled_events.decrementAndGet() > 0);
+                } while (scheduledEvents.decrementAndGet() > 0);
             } finally {
                 sslLock.unlock();
             }
@@ -342,11 +339,7 @@ class SslHandler {
      */
     /* no qualifier */void messageReceived(NextFilter nextFilter, ByteBuffer buf) throws SSLException {
         if (LOGGER.isDebugEnabled()) {
-            if (!isOutboundDone()) {
-                LOGGER.debug("{} Processing the received message", sslFilter.getSessionInfo(session));
-            } else {
-                LOGGER.debug("{} Processing the received message", sslFilter.getSessionInfo(session));
-            }
+            LOGGER.debug("{} Processing the received message", sslFilter.getSessionInfo(session));
         }
 
         // append buf to inNetBuffer
@@ -400,13 +393,13 @@ class SslHandler {
      * @return buffer with data
      */
     /* no qualifier */IoBuffer fetchAppBuffer() {
-        if (this.appBuffer == null) {
+        if (appBuffer == null) {
             return IoBuffer.allocate(0);
         } else {
-            IoBuffer appBuffer = this.appBuffer.flip();
-            this.appBuffer = null;
+            IoBuffer newAppBuffer = appBuffer.flip();
+            appBuffer = null;
 
-            return appBuffer.shrink();
+            return newAppBuffer.shrink();
         }
     }
 
@@ -417,11 +410,13 @@ class SslHandler {
      */
     /* no qualifier */IoBuffer fetchOutNetBuffer() {
         IoBuffer answer = outNetBuffer;
+        
         if (answer == null) {
             return emptyBuffer;
         }
 
         outNetBuffer = null;
+        
         return answer.shrink();
     }
 
@@ -534,7 +529,6 @@ class SslHandler {
         for (;;) {
             switch (handshakeStatus) {
             case FINISHED:
-            case NOT_HANDSHAKING:
                 if (LOGGER.isDebugEnabled()) {
                     LOGGER.debug("{} processing the FINISHED state", sslFilter.getSessionInfo(session));
                 }
@@ -545,7 +539,6 @@ class SslHandler {
                 // Send the SECURE message only if it's the first SSL handshake
                 if (firstSSLNegociation && session.containsAttribute(SslFilter.USE_NOTIFICATION)) {
                     // SESSION_SECURED is fired only when it's the first handshake
-                    firstSSLNegociation = false;
                     scheduleMessageReceived(nextFilter, SslFilter.SESSION_SECURED);
                 }
 
@@ -583,6 +576,7 @@ class SslHandler {
                 break;
 
             case NEED_WRAP:
+            case NOT_HANDSHAKING:
                 if (LOGGER.isDebugEnabled()) {
                     LOGGER.debug("{} processing the NEED_WRAP state", sslFilter.getSessionInfo(session));
                 }
@@ -597,14 +591,13 @@ class SslHandler {
                 SSLEngineResult result;
                 createOutNetBuffer(0);
 
-                for (;;) {
+                result = sslEngine.wrap(emptyBuffer.buf(), outNetBuffer.buf());
+
+                while ( result.getStatus() == SSLEngineResult.Status.BUFFER_OVERFLOW ) {
+                    outNetBuffer.capacity(outNetBuffer.capacity() << 1);
+                    outNetBuffer.limit(outNetBuffer.capacity());
+
                     result = sslEngine.wrap(emptyBuffer.buf(), outNetBuffer.buf());
-                    if (result.getStatus() == SSLEngineResult.Status.BUFFER_OVERFLOW) {
-                        outNetBuffer.capacity(outNetBuffer.capacity() << 1);
-                        outNetBuffer.limit(outNetBuffer.capacity());
-                    } else {
-                        break;
-                    }
                 }
 
                 outNetBuffer.flip();
@@ -662,10 +655,11 @@ class SslHandler {
                     throw newSsle;
                 }
 
-                IoBuffer outNetBuffer = fetchOutNetBuffer();
-                if (outNetBuffer != null && outNetBuffer.hasRemaining()) {
+                IoBuffer currentOutNetBuffer = fetchOutNetBuffer();
+                
+                if (currentOutNetBuffer != null && currentOutNetBuffer.hasRemaining()) {
                     writeFuture = new DefaultWriteFuture(session);
-                    sslFilter.filterWrite(nextFilter, session, new DefaultWriteRequest(outNetBuffer, writeFuture));
+                    sslFilter.filterWrite(nextFilter, session, new DefaultWriteRequest(currentOutNetBuffer, writeFuture));
                 }
             }
         } finally {
@@ -745,9 +739,7 @@ class SslHandler {
         }
 
         SSLEngineResult res;
-
-        Status status = null;
-        HandshakeStatus handshakeStatus = null;
+        Status status;
 
         do {
             // Decode the incoming data
@@ -810,6 +802,10 @@ class SslHandler {
         return copy;
     }
 
+    /**
+     * {@inheritDoc}
+     */
+    @Override
     public String toString() {
         StringBuilder sb = new StringBuilder();
 
