@@ -36,6 +36,9 @@ import org.apache.mina.proxy.utils.ByteUtilities;
  * @since MINA 2.0.0-M3
  */
 public class NTLMUtilities implements NTLMConstants {
+    private NTLMUtilities() {
+    }
+    
     /**
      * @see #writeSecurityBuffer(short, short, int, byte[], int)
      * 
@@ -43,7 +46,7 @@ public class NTLMUtilities implements NTLMConstants {
      * @param bufferOffset The offset in the security buffer
      * @return Th created buffer
      */
-    public final static byte[] writeSecurityBuffer(short length, int bufferOffset) {
+    public static final byte[] writeSecurityBuffer(short length, int bufferOffset) {
         byte[] b = new byte[8];
         writeSecurityBuffer(length, length, bufferOffset, b, 0);
 
@@ -65,7 +68,7 @@ public class NTLMUtilities implements NTLMConstants {
      * @param b the buffer in which we write the security buffer
      * @param offset the offset at which to write to the b buffer
      */
-    public final static void writeSecurityBuffer(short length, short allocated, int bufferOffset, byte[] b, int offset) {
+    public static final void writeSecurityBuffer(short length, short allocated, int bufferOffset, byte[] b, int offset) {
         ByteUtilities.writeShort(length, b, offset);
         ByteUtilities.writeShort(allocated, b, offset + 2);
         ByteUtilities.writeInt(bufferOffset, b, offset + 4);
@@ -82,7 +85,7 @@ public class NTLMUtilities implements NTLMConstants {
      * @param b the target byte array
      * @param offset the offset at which to write in the array
      */
-    public final static void writeOSVersion(byte majorVersion, byte minorVersion, short buildNumber, byte[] b,
+    public static final void writeOSVersion(byte majorVersion, byte minorVersion, short buildNumber, byte[] b,
             int offset) {
         b[offset] = majorVersion;
         b[offset + 1] = minorVersion;
@@ -101,7 +104,7 @@ public class NTLMUtilities implements NTLMConstants {
      * 
      * @return a NTLM OS version byte buffer
      */
-    public final static byte[] getOsVersion() {
+    public static final byte[] getOsVersion() {
         String os = System.getProperty("os.name");
 
         if ((os == null) || !os.toUpperCase().contains("WINDOWS")) {
@@ -177,9 +180,9 @@ public class NTLMUtilities implements NTLMConstants {
      * <code>NTLMConstants.DEFAULT_OS_VERSION</code> is used
      * @return the type 1 message
      */
-    public final static byte[] createType1Message(String workStation, String domain, Integer customFlags,
+    public static final byte[] createType1Message(String workStation, String domain, Integer customFlags,
             byte[] osVersion) {
-        byte[] msg = null;
+        byte[] msg;
 
         if (osVersion != null && osVersion.length != 8) {
             throw new IllegalArgumentException("osVersion parameter should be a 8 byte wide array");
@@ -233,7 +236,7 @@ public class NTLMUtilities implements NTLMConstants {
      * @return the position where the next security buffer will be written
      * @throws IOException if writing to the ByteArrayOutputStream fails
      */
-    public final static int writeSecurityBufferAndUpdatePointer(ByteArrayOutputStream baos, short len, int pointer)
+    public static final int writeSecurityBufferAndUpdatePointer(ByteArrayOutputStream baos, short len, int pointer)
             throws IOException {
         baos.write(writeSecurityBuffer(len, pointer));
 
@@ -246,7 +249,7 @@ public class NTLMUtilities implements NTLMConstants {
      * @param msg the type 2 message byte array
      * @return the challenge
      */
-    public final static byte[] extractChallengeFromType2Message(byte[] msg) {
+    public static final byte[] extractChallengeFromType2Message(byte[] msg) {
         byte[] challenge = new byte[8];
         System.arraycopy(msg, 24, challenge, 0, 8);
 
@@ -259,7 +262,7 @@ public class NTLMUtilities implements NTLMConstants {
      * @param msg the type 2 message byte array
      * @return the proxy flags as an int
      */
-    public final static int extractFlagsFromType2Message(byte[] msg) {
+    public static final int extractFlagsFromType2Message(byte[] msg) {
         byte[] flagsBytes = new byte[4];
 
         System.arraycopy(msg, 20, flagsBytes, 0, 4);
@@ -276,7 +279,7 @@ public class NTLMUtilities implements NTLMConstants {
      * @param securityBufferOffset the offset at which to read the security buffer
      * @return a new byte array holding the data pointed by the security buffer
      */
-    public final static byte[] readSecurityBufferTarget(byte[] msg, int securityBufferOffset) {
+    public static final byte[] readSecurityBufferTarget(byte[] msg, int securityBufferOffset) {
         byte[] securityBuffer = new byte[8];
 
         System.arraycopy(msg, securityBufferOffset, securityBuffer, 0, 8);
@@ -300,7 +303,7 @@ public class NTLMUtilities implements NTLMConstants {
      * @throws UnsupportedEncodingException if unable to use the
      * needed UTF-16LE or ASCII charsets
      */
-    public final static String extractTargetNameFromType2Message(byte[] msg, Integer msgFlags)
+    public static final String extractTargetNameFromType2Message(byte[] msg, Integer msgFlags)
             throws UnsupportedEncodingException {
         // Read the security buffer to determine where the target name
         // is stored and what it's length is
@@ -324,7 +327,7 @@ public class NTLMUtilities implements NTLMConstants {
      * type 2 message
      * @return the target info
      */
-    public final static byte[] extractTargetInfoFromType2Message(byte[] msg, Integer msgFlags) {
+    public static final byte[] extractTargetInfoFromType2Message(byte[] msg, Integer msgFlags) {
         int flags = msgFlags == null ? extractFlagsFromType2Message(msg) : msgFlags;
 
         if (!ByteUtilities.isFlagSet(flags, FLAG_NEGOTIATE_TARGET_INFO)) {
@@ -347,7 +350,7 @@ public class NTLMUtilities implements NTLMConstants {
      * @throws UnsupportedEncodingException if unable to use the
      * needed UTF-16LE or ASCII charsets
      */
-    public final static void printTargetInformationBlockFromType2Message(byte[] msg, Integer msgFlags, PrintWriter out)
+    public static final void printTargetInformationBlockFromType2Message(byte[] msg, Integer msgFlags, PrintWriter out)
             throws UnsupportedEncodingException {
         int flags = msgFlags == null ? extractFlagsFromType2Message(msg) : msgFlags;
 
@@ -400,29 +403,20 @@ public class NTLMUtilities implements NTLMConstants {
     }
 
     /**
-     * @see <a
-     *      href="http://davenport.sourceforge.net/ntlm.html#theType3Message">NTLM
-     *      message type</a>
+     * @see <a href="http://davenport.sourceforge.net/ntlm.html#theType3Message">NTLM message type</a>
      * 
-     * @param user
-     *            the user name
-     * @param password
-     *            the user password
-     * @param challenge
-     *            the challenge response
-     * @param target
-     *            the target name
-     * @param workstation
-     *            the client workstation's name
-     * @param serverFlags
-     *            the flags set by the client
-     * @param osVersion
-     *            the os version of the client
+     * @param user the user name
+     * @param password the user password
+     * @param challenge the challenge response
+     * @param target the target name
+     * @param workstation the client workstation's name
+     * @param serverFlags the flags set by the client
+     * @param osVersion the os version of the client
      * @return the type 3 message
      */
-    public final static byte[] createType3Message(String user, String password, byte[] challenge, String target,
+    public static final byte[] createType3Message(String user, String password, byte[] challenge, String target,
             String workstation, Integer serverFlags, byte[] osVersion) {
-        byte[] msg = null;
+        byte[] msg;
 
         if (challenge == null || challenge.length != 8) {
             throw new IllegalArgumentException("challenge[] should be a 8 byte wide array");
