@@ -20,11 +20,50 @@
 package org.apache.mina.http.api;
 
 /**
+ * The HTTP method, one of GET, HEAD, POST, PUT, DELETE, OPTIONS, TRACE, CONNECT
  * 
- * @author The Apache MINA Project (dev@mina.apache.org)
- * 
+ * @author <a href="http://mina.apache.org">Apache MINA Project</a>
  */
 public enum HttpMethod {
-
-    GET, HEAD, POST, PUT, DELETE, OPTIONS, TRACE, CONNECT
+    /** The OPTIONS method */
+    OPTIONS, 
+    
+    /** The GET method */
+    GET, 
+    
+    /** The HEAD method */
+    HEAD, 
+    
+    /** The POST method */
+    POST, 
+    
+    /** The PUT method */
+    PUT, 
+    
+    /** The PATCH method */
+    PATCH,
+    
+    /** The COPY method */
+    COPY,
+    
+    /** The MOVE method */
+    MOVE,
+    
+    /** The DELETE method */
+    DELETE, 
+    
+    /** The LINK method */
+    LINK,
+    
+    /** The UNLINK method */
+    UNLINK,
+        
+    /** The TRACE method */
+    TRACE, 
+    
+    /** The WRAPPED method */
+    WRAPPED,
+    
+    /** The CONNECT method */
+    CONNECT
 }
